# RETRO-VIZ
RETRO-VIZ is a method for estimating and explaining the error in regression problems.

## Install
retroviz can be installed from PyPI using `pip install retroviz`.

## Documentation

For documentation and examples of how to use `retroviz`, we refer to the notebooks at https://github.com/kimdebie/retroviz-tutorial.
